@@ -32,6 +32,7 @@ to internationalize software.
 =cut
 
 use Carp;
+use POSIX qw(:locale_h);
 
 require Exporter;
 require DynaLoader;
@@ -45,7 +46,7 @@ BEGIN {
 	import Encode if ($encode_available);
 }
 
-$VERSION = "1.05" ;
+$VERSION = "1.06" ;
 
 %EXPORT_TAGS = (
 
@@ -235,7 +236,7 @@ sub DESTROY {
 gettext(), dgettext(), and dcgettext() attempt to retrieve a string
 matching their C<msgid> parameter within the context of the current
 locale. dcgettext() takes the message's category and the text domain
-as parameters while dcgettext() defaults to the LC_MESSAGES category
+as parameters while dgettext() defaults to the LC_MESSAGES category
 and gettext() defaults to LC_MESSAGES and uses the current text domain.
 If the string is not found in the database, then C<msgid> is returned.
 
@@ -267,7 +268,7 @@ not provide it.
 
 =head1 VERSION
 
-1.05.
+1.06.
 
 =head1 SEE ALSO
 
@@ -275,7 +276,7 @@ gettext(3i), gettext(1), msgfmt(1)
 
 =head1 AUTHOR
 
-Phillip Vandry <vandry@TZoNE.ORG>
+Kim Vandry <vandry@TZoNE.ORG>
 
 =cut
 
